package com.zd.exam.service;

import com.zd.exam.domain.ElResources;
import org.springframework.web.multipart.MultipartFile;

import java.net.URISyntaxException;
import java.util.List;

/**
 * 课件资源Service接口
 *
 * @author liubo
 * @date 2021-12-07
 */
public interface IElResourcesService {
    /**
     * 查询课件资源
     *
     * @param id 课件资源主键
     * @return 课件资源
     */
    public ElResources selectElResourcesById(Long id);

    /**
     * 查询课件资源列表
     *
     * @param elResources 课件资源
     * @return 课件资源集合
     */
    public ElResources selectElResourcesCate(ElResources elResources);

    /**
     * 查询课件资源列表
     *
     * @param elResources 课件资源
     * @return 课件资源集合
     */
    public List<ElResources> selectElResourcesList(ElResources elResources);


    /**
     * 查询所有课件资源列表
     *
     * @return 课件资源集合
     */
    public List<ElResources> selectElResourcesListALL();

    /**
     * 新增课件资源
     * @return 结果
     */
    public ElResources insertElResources(ElResources elResources, MultipartFile file);


    /**
     * 新增课件资源
     * @return 结果
     */
    public ElResources insertElResources(ElResources elResources);

    /**
     * 修改课件资源
     *
     * @param elResources 课件资源
     * @return 结果
     */
    public int updateElResources(ElResources elResources, MultipartFile file);

    /**
     * 修改课件资源
     *
     * @param elResources 课件资源
     * @return 结果
     */
    public int updateElResources(ElResources elResources, int type);

    /**
     * 批量删除课件资源
     *
     * @param ids 需要删除的课件资源主键集合
     * @return 结果
     */
    public int deleteElResourcesByIds(Long[] ids);

    /**
     * 删除课件资源信息
     *
     * @param id 课件资源主键
     * @return 结果
     */
    public int deleteElResourcesById(Long id);
}
